@@ -13,6 +13,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/
  - 更新履歴：
+ -      [2007/06/20] XSS対応
  -      [2006/09/21] RKT_pager::getUrlSelf()にPATH_INFO_KEYの分岐を追加
  -      [2006/09/04] RKT_pager::getUrlSelf()を追加
  -      [2006/05/07] Group by 句の位置不具合を解消
@@ -90,7 +91,7 @@ class RKT_pager
     function RKT_pager(&$conn, $offset=0, $limit=5)
     {
         $this->conn   = &$conn;        // コピーの方が良いかも
-        $this->offset = empty($offset)?0:$offset;
+        $this->offset = is_numeric($offset)?$offset:0;
         $this->limit  = $limit;
         $this->maxrow = null;
         $this->infos  = null;
