@@ -21,6 +21,8 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/17] コミュニティ：トピック、イベント、記事、アンケート権限追加
+ -      [2007/06/17] あしあと追加
  -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/09/20] $this->base['uri_separator']を追加
  -      [2006/08/26] コミュニティ情報をメンバ変数に所持
@@ -185,6 +187,10 @@ class WAP_community extends RKT_webapp
                 'com.id as id,'.
                 'com.ref_account as ref_account,'.
                 'com.visibility as visibility,'.
+                'com.topic_flag as topic_flag,'.
+                'com.event_flag as event_flag,'.
+                'com.item_flag as item_flag,'.
+                'com.enquete_flag as enquete_flag,'.
                 'com.community as community,'.
                 'pic.filename as href,'.
                 'pic.thumbnail as src,'.
@@ -279,6 +285,106 @@ class WAP_community extends RKT_webapp
         $this->community['is_member'] = !empty($result['ct']);
         $this->base['is_member'] = $this->community['is_member'];
     }
+
+    /**
+     * あしあと処理
+     *
+     * @access public
+     * @return boolean
+     */
+    function doFootprint()
+    {
+        $this->insert_footprint();
+        $this->insert_accesslog();
+    }
+
+    /**
+     * 足跡の挿入
+     *
+     * @access private
+     * @return integer  データ操作結果
+     */
+    function insert_footprint()
+    {
+        $to_date = sql_query::toDate('modify');
+        $sql = 
+            'SELECT '.
+                'id '.
+            'FROM '.
+                DB_PREFIX.'com_footprint '.
+            'WHERE '.
+                $to_date." = '".date('Y-m-d')."' AND ".
+                'ref_community = '.$this->ref_community.' AND '.
+                'ref_account = '.$this->account['id'];
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        if (empty($result['id'])){
+            $sql =
+                'INSERT INTO '.
+                    DB_PREFIX.'com_footprint('.
+                        'modify,'.
+                        'ref_community,'.
+                        'ref_account '.
+                    ') VALUES ('.
+                        "'".date('Y-m-d H:i:s')."',".
+                        $this->ref_community.','.
+                        $this->account['id'].
+                    ')';
+        } else {
+            $sql =
+                'UPDATE '.
+                    DB_PREFIX.'com_footprint '.
+                'SET '.
+                    "modify = '".date('Y-m-d H:i:s')."' ".
+                'WHERE '.
+                    'id='.$result['id'];
+        }
+        return $this->objdb->exec($sql);
+    }
+
+    /**
+     * アクセスログの挿入
+     *
+     * @access private
+     * @return boolean 正常時：真
+     */
+    function insert_accesslog()
+    {
+        $sql = 
+            'SELECT '.
+                'count(*) as ct '.
+            'FROM '.
+                DB_PREFIX.'com_accesslog '.
+            'WHERE '.
+                "modify > '".date('Y-m-d H:i:s',time()-3600)."' AND ".
+                'ref_community = '.$this->ref_community.' AND '.
+                'ref_account = '.$this->account['id'];
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetch(PDO_FETCH_ASSOC);
+        $stmt->closeCursor();
+
+        if (empty($result['ct'])){
+            $unique = 1;
+            $sql=
+                'INSERT INTO '.
+                    DB_PREFIX.'com_accesslog('.
+                        'modify,'.
+                        'ref_community,'.
+                        'ref_account,'.
+                        'unique_flag '.
+                    ') VALUES ('.
+                        "'".date('Y-m-d H:i:s')."',".
+                        $this->ref_community.','.
+                        $this->account['id'].','.
+                        "'".$unique."'".
+                    ')';
+            $this->ins_accesslog = $this->objdb->exec($sql);
+        }
+    }
 }
 // WAP_communityの終了
 ?>
