@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  -  更新履歴：
+ -      [2007/06/20] XSS対応
  -      [2007/05/27] 携帯端末IDによる自動ログイン処理の追加
  -      [2006/07/10] 作成
  - ======================================================================== */
@@ -38,6 +39,12 @@ require_once WEBAPP_LIB_DIR.'wap_public.php';
  */
 class webapp extends WAP_public
 {
+    /**
+     * URL
+     * @var integer
+     */
+    var $url = '';
+
     /**
      * 実行処理
      *
@@ -47,8 +54,10 @@ class webapp extends WAP_public
     function execute()
     {
         $this->setTemplateFile('public/login/entrance.tpl');
-        $url = empty($_REQUEST['url'])? '':$_REQUEST['url'];
-        $url = $this->get_sidurl($url);
+
+        /* URL引数の取得 */
+        $this->setSafety('url','_REQUEST','string');
+        $url = $this->get_sidurl($this->url);
 
         $objauth = new RKT_auth();
         if ($objauth->autoLoginUserAgentID()){
