@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/05/27] 自動ログイン部分の追加
  -      [2006/07/10] 作成
  - ======================================================================== */
 
@@ -54,9 +55,9 @@ class webapp extends WAP_public
         /* URL引数の取得 */
         $this->setSafety('autologin','_POST');
 
-        $url = HTTP_ACTION.'private/home/menu/'.$this->sid.'/';
-        $url = empty($_REQUEST['url'])?$url:$_REQUEST['url'];
         $session_id = empty($_REQUEST['sid'])?null:$_REQUEST['sid'];
+        $url = HTTP_ACTION.'private/home/menu/'.$session_id.'/';
+        $url = empty($_REQUEST['url'])?$url:$_REQUEST['url'];
 
         $objauth = new RKT_auth($session_id);
         if (!$objauth->logIn()){
