@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/02] リスト選択時のデフォルト値エラー修正
  -      [2006/07/31] 作成
  - ======================================================================== */
 
@@ -388,9 +389,8 @@ class act_enquete extends RKT_validate
                                             'day'=>  $date[2]
                                         );
             } // if ($form_type == FORM_TYPE_TEXT || $form_type == FORM_TYPE_TEXTAREA)
-            
-            $this->visibility[$key] = $value['visibility'];
-            
+            $this->requests[$flag]  = $value['visibility'];
+            $this->visibility[$key] = $value['visibility'];            
         } // foreach ($result as $value)
     }
 
