@@ -395,40 +395,5 @@ class webapp extends WAP_admin
         
         return true;
     }
-
-    /****************************************************************/
-    /**********    ポータルへのリクエスト処理     *******************/
-    /****************************************************************/
-    /**
-     * ポータル用トピック・イベントデータの削除
-     *
-     * @access private
-     * @return boolean
-     */
-    function request_delete()
-    {
-        include_once LIB_DIR.'PEAR/HTTP/Request.php';
-
-        $req =& new HTTP_Request(WAP_HTTP_REQUEST_URL.'exec/public/edit/delete_community/');
-        $req->setMethod(HTTP_REQUEST_METHOD_POST);
-
-        $req->addPostData('ref_sns', SNS_ID);
-        $req->addPostData('community_id', $this->id);
-
-        $req->addPostData('delete', '1');
-
-        if (!PEAR::isError($req->sendRequest())) {
-             $response = $req->getResponseBody();
-        } else {
-             $response = "error";
-        }
-
-        $result = false;
-        if (preg_match("/<error>0<\/error>/i", $response)){
-            $result = true;
-        }
-
-        return $result;
-    }
 } // webapp
 ?>
