@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/06/17] 書き込み権限追加
  -      [2006/07/10] 作成
  - ======================================================================== */
 
@@ -260,6 +261,14 @@ class webapp extends WAP_community
      */
     function do_query()
     {
+        /* 作成権限 */
+        if ($this->community['event_flag'] == PERMISSION_ADMIN){
+            if (!$this->base['admin']){
+                $this->Assign('permission_denied', true);
+                return false;
+            }
+        } // if ($this->community['event_flag'] == PERMISSION_ADMIN)
+
         if (!empty($this->id)){
             $this->objmnp->setCurID($this->id);
         } else {
