@@ -173,6 +173,10 @@ class webapp extends WAP_friend
     {
         /* 絞込条件の取得 */
         $validates = array(
+            'keyword'=> array(
+                'type'=> 'string',
+                'option'=> array()
+            ),
             'day'=> array(
                 'type'=> 'date',
                 'option'=> array('format'=>'%Y-%m-%d')
@@ -202,6 +206,17 @@ class webapp extends WAP_friend
         $where = array();
         $conditions = $this->get_condition();
 
+        /* キーワード検索 */
+        $keys = array();
+        if (!empty($conditions['keyword'])){
+            $keywords = explode(' ',$conditions['keyword']);
+            foreach ($keywords as $keyword){
+                $keys[] = '('.
+                    "ent.subject like '%".$keyword."%'".' OR '.
+                    "ent.body like '%".$keyword."%'".')';
+            }
+            $where[] = '('.implode(' OR ',$keys) .') ';
+        }
         /* 日付 */
         if (!empty($conditions['day'])){
             $date_format = sql_query::dateFormat('ent.regist_date','%Y-%m-%d');
