@@ -21,6 +21,7 @@
  -      yujiro@rakuto.net
  -      http://rakuto.net/rktSNS/
  - 更新履歴：
+ -      [2007/02/12] コミュニティメンバーステータスをビットフラグに変更
  -      [2006/09/04] コミュニティ掲示板の一覧が表示されないエラーを修正
  -      [2006/07/10] 表示整形の不具合修正
  -      [2006/08/27] 基礎情報を親クラスから引っ張るように修正
@@ -28,6 +29,7 @@
  - ======================================================================== */
 
 /* =-=- モジュール等の読み込み -=-= */
+require_once WEBAPP_LIB_DIR.'sql_query.php';
 require_once WEBAPP_LIB_DIR.'wap_private.php';
 
 /**
@@ -230,7 +232,25 @@ class webapp extends WAP_private
     {
         $sql=
             'SELECT '.
-                'count(*) as ct '.
+                'cmt.ref_entry as ref_entry '.
+            'FROM '.
+                DB_PREFIX.'dia_diary dia,'.
+                DB_PREFIX.'dia_comment cmt '.
+            'WHERE '.
+                'dia.id = cmt.ref_diary AND '.
+                'cmt.flag = '.MESSAGE_FLAG_UNREAD.' AND '.
+                'dia.ref_account = '.$this->account['id'].' '.
+            'GROUP BY '.
+                'cmt.ref_entry';
+        $stmt = $this->objdb->prepare($sql); 
+        $stmt->execute(); 
+        $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
+
+        $this->Assign('new_comment', count($result));
+
+        $sql=
+            'SELECT '.
+                'cmt.ref_entry ref_entry '.
             'FROM '.
                 DB_PREFIX.'dia_diary dia,'.
                 DB_PREFIX.'dia_comment cmt '.
@@ -243,7 +263,7 @@ class webapp extends WAP_private
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
         $stmt->closeCursor();
 
-        $this->Assign('new_comment', $result['ct']);
+        $this->Assign('new_comment_entry', $result['ref_entry']);
     }
 
     /**
@@ -366,9 +386,7 @@ class webapp extends WAP_private
             'WHERE '.
                 'com.id = nms.ref_community AND '.
                 'com.avail = '.AVAIL_ENABLE.' AND '.
-                '(nms.status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                'nms.status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                'nms.status = '.STATUS_COMMUNITY_ADMIN.') AND '.
+                sql_query::bitFlag('nms.status & '.STATUS_COMMUNITY_MEMBERS).' AND '.
                 'nms.ref_account = '.$this->account['id'].' '.
             'ORDER BY '.
                 'com.modify DESC '.
@@ -427,9 +445,7 @@ class webapp extends WAP_private
                 DB_PREFIX.'com_names '.
             'WHERE '.
                 'ref_account = '.$this->account['id'].' AND '.
-                '(status = '.STATUS_COMMUNITY_MEMBER.' OR '.
-                 'status = '.STATUS_COMMUNITY_CHANGE.' OR '.
-                 'status = '.STATUS_COMMUNITY_ADMIN.')';
+                sql_query::bitFlag('status & '.STATUS_COMMUNITY_MEMBERS);
         $stmt = $this->objdb->prepare($sql); 
         $stmt->execute(); 
         $result = $stmt->fetch(PDO_FETCH_ASSOC);
@@ -452,7 +468,7 @@ class webapp extends WAP_private
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
                 'com.modify as modify,'.
-                'count(com.id) as ct,'.
+                'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
                 DB_PREFIX.'act_account act,'.
@@ -498,7 +514,8 @@ class webapp extends WAP_private
                 'tpc.id as ref_topic,'.
                 'tpc.topic as topic,'.
                 'tpc.modify as modify,'.
-                'count(cmt.id) as ct '.
+                'tpc.status as status,'.
+                'tpc.post as ct '.
             'FROM '.
                 DB_PREFIX.'com_topic tpc '.
                     'LEFT JOIN '.DB_PREFIX.'com_comment cmt '.
@@ -528,6 +545,14 @@ class webapp extends WAP_private
         $result = $stmt->fetchAll(PDO_FETCH_ASSOC);
 
         $this->Assign('topics', $result);
+
+        $urls = array(
+            STATUS_TOPIC_BULLETIN=> 'bbs/browse',
+            STATUS_TOPIC_EVENT=>    'bbs/browse',
+            STATUS_TOPIC_ITEM=>     'item/browse',
+            STATUS_TOPIC_ENQUETE=>  'item/browse',
+        );
+        $this->Assign('com_urls', $urls);
     }
 
     /**
@@ -657,7 +682,7 @@ class webapp extends WAP_private
                 'act.id as ref_friend,'.
                 'pro.nickname as nickname,'.
                 'com.modify as modify,'.
-                'count(com.id) as ct,'.
+                'ent.post as ct,'.
                 'ent.subject as subject '.
             'FROM '.
                 DB_PREFIX.'act_account act,'.
