@@ -185,23 +185,27 @@ $webapp->execute();
 
 	</head>
 	<body>
-		<!-- start:ヘッダー -->
-		<div id="header">
-			<div class="left">
-				<a href="./"><img src="./resource/img/header/logo.gif" width="163" height="94" alt="{$smarty.const.WAP_SYSTEM_NAME}" /></a>
-			</div>
-			<div class="left">
-				<div class="search"></div>
-			</div>
-			<div class="right">
-				<div class="sponsor">
-					<a href="http://rakuto.net/rktSNS/"><img  src="./resource/img/sponsor/ads.gif" width="468" height="60" alt="広告" /></a>
-				</div>
-				<div id="headerbar">
-				</div>
-			</div>
-		</div>
-		<!-- /finish:ヘッダー -->
+		<table id="frame" align="center" cellpadding="0" cellspacing="0"><tbody>
+			<tr><td id="frame_main">
+				<!-- start:ヘッダー -->
+				<table id="header" align="center" cellpadding="0" cellspacing="0"><tbody>
+					<tr>
+						<td rowspan="2"><a href="./"><img src="./resource/img/header/logo.gif" width="163" height="94" alt="{$smarty.const.WAP_SYSTEM_NAME}" /></a></td>
+						<td rowspan="2">
+						</td>
+						<td><a href="http://rakuto.net/rktSNS/"><img  src="./resource/img/sponsor/ads.gif" width="468" height="60" alt="広告" /></a></td>
+					</tr>
+					<tr>
+						<td id="headerbar">
+							<ul>
+								<li><a href="<?php echo $_SERVER['PHP_SELF']; ?>?page=check">Step1</a></li>
+								<li><a href="<?php echo $_SERVER['PHP_SELF']; ?>?page=config">Step2</a></li>
+								<li><a href="<?php echo $_SERVER['PHP_SELF']; ?>?page=admin">Step3</a></li>
+							</ul>
+						</td>
+					</tr>
+				<tbody></table>
+				<!-- /finish:ヘッダー -->
 
 		<!-- start:メインコンテンツ -->
 		<div id="content">
@@ -331,8 +335,15 @@ $webapp->execute();
 		</div>
 		<!-- /finish:メインコンテンツ -->
 
-		<!-- start:フッター -->
-		<div id="footer"></div>
-		<!-- /finish:フッター -->
+
+				<!-- start:フッター -->
+				<div id="footer">
+					<div class="text-center">
+					</div>
+					<div class="copyright">rktSNS&nbsp;&nbsp;&nbsp;</div>
+				</div>
+				<!-- /finish:フッター -->
+			</td></tr>
+		</tbody></table>
 	</body>
 </html>
\ No newline at end of file
